==> backdrop-2.0.6.tgz: package/module/index.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

import ElementMonitor from 'element-monitor';
import * as EventBridge from 'event-bridge';
import * as TheBox from 'the-dom-box';
import GapGrid from '@fczbkk/gap-grid';

var noop = function noop() {};

/**
 * Config object for Backdrop.
 * @typedef BackdropOptions
 * @property {string} backdrop_class - `"backdrop"` Class name added to all backdrop elements.
 * @property {number} z_index - `1000` Z-index added to all backdrop elements.
 * @property {number} padding - `5` Size of padding around target elements, in pixels.
 * @property {string} color - `"#000000"` Color of the backdrop elements.
 * @property {number} opacity - `0.5` Opacity of the backdrop elements. Must be number between 1 (fully opaque) and 0 (no opacity).
 * @property {boolean} hide_on_click - `true` If true, the backdrop will hide when user clicks on it.
 * @property {boolean} cover - `false` If true, the target elements will be covered by invisible elements which will prevent user from clicking on them. The cover elements also react to click when `hide_on_click` is enabled.
 * @property {boolean} watch - `false` If true, the backdrop will watch target elements and react to the changes in their position, size and/or visibility. This feature can have impact on performance, so it is turned off by default.
 * @property {number} watch_interval - `500` Interval between checks when watching for changes, in milliseconds.
 * @property {Function} onShow - Function to be called when backdrop is shown.
 * @property {Function} onHide - Function to be called when backdrop is hidden.
 */
var default_options = {
  backdrop_class: 'backdrop',
  z_index: 1000,
  padding: 5,
  color: '#000000',
  opacity: 0.5,
  hide_on_click: true,
  cover: false,
  watch: false,
  watch_interval: 500,
  onShow: noop,
  onHide: noop
};

/**
 * Class representing a Backdrop.
 * @name Backdrop
 */

var Backdrop = function () {

  /**
   * Create a Backdrop object.
   * @param {BackdropOptions} custom_options
   */
  function Backdrop() {
    var custom_options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

    _classCallCheck(this, Backdrop);

    this.backdrops = [];
    this.covers = [];
    this.is_active = false;
    this.options = _extends({}, default_options, custom_options);

    this.element_monitor = new ElementMonitor(null, {
      interval: this.options.watch_interval,
      onChange: this.draw.bind(this)
    });

    EventBridge.add(window, 'resize', this.redraw.bind(this));
  }

  /**
   * Updates existing options.
   * @param {BackdropOptions} custom_options
   */


  _createClass(Backdrop, [{
    key: 'setOptions',
    value: function setOptions() {
      var custom_options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

      _extends(this.options, custom_options);
    }

    /**
     * Adds element(s) to target elements.
     * @param {Element|string} element - Reference to an element or CSS selector.
     */

  }, {
    key: 'add',
    value: function add(element) {
      this.element_monitor.elements.add(element);
      this.redraw();
    }

    /**
     * Removes element(s) from target elements.
     * @param {Element|string} element - Reference to an element or CSS selector.
     */

  }, {
    key: 'remove',
    value: function remove(element) {
      this.element_monitor.elements.remove(element);
      this.redraw();
    }

    /**
     * Sets new target element(s).
     * @param {Element|string} element - Reference to an element or CSS selector.
     */

  }, {
    key: 'set',
    value: function set(element) {
      this.element_monitor.elements.set(element);
      this.redraw();
    }

    // When document is zoomed, element sizes and positions sometimes return numbers with crazy ammount of decimal places. This sometimes causes problem with blank lines showing in the backdrops. The easiest way to prevent this glitch is to round all the numbers to integers.

  }, {
    key: 'sanitizeEmptySpace',
    value: function sanitizeEmptySpace(box) {
      Object.keys(box).forEach(function (key) {
        box[key] = Math.round(box[key]);
      });
      return box;
    }
  }, {
    key: 'removeBackdrops',
    value: function removeBackdrops() {
      this.backdrops.forEach(function (element) {
        element.parentNode.removeChild(element);
      });
      this.backdrops = [];
    }
  }, {
    key: 'addBackdrops',
    value: function addBackdrops(gaps) {
      var _this = this;

      var canvas = TheBox.getBox('document');
      var gap_grid = new GapGrid(canvas, gaps, { round_points: true });
      var empty_spaces = gap_grid.generate();

      empty_spaces.forEach(function (empty_space) {
        _this.backdrops.push(_this.createBackdrop(_this.sanitizeEmptySpace(empty_space)));
      });

      return this.backdrops;
    }
  }, {
    key: 'createBackdrop',
    value: function createBackdrop(box) {
      var element = document.createElement('div');
      element.className = this.options.backdrop_class;

      var ie_opacity = this.options.opacity * 100;

      var properties = {
        position: 'absolute',
        left: box.left + 'px',
        top: box.top + 'px',
        width: box.width + 'px',
        height: box.height + 'px',
        zIndex: this.options.z_index,
        backgroundColor: this.options.color,
        opacity: this.options.opacity,
        // IE8
        MsFilter: 'progid:DXImageTransform.Microsoft.Alpha(Opacity=' + ie_opacity + ')',
        // IE5-7
        filter: 'alpha(opacity=' + ie_opacity + ')'
      };

      Object.keys(properties).forEach(function (key) {
        element.style[key] = properties[key];
      });

      if (this.options.hide_on_click) {
        EventBridge.add(element, 'click', this.hide.bind(this));
      }

      document.body.appendChild(element);
      return element;
    }
  }, {
    key: 'addCover',
    value: function addCover(box) {
      var element = document.createElement('div');

      var properties = {
        position: 'absolute',
        left: box.left + 'px',
        top: box.top + 'px',
        width: box.width + 'px',
        height: box.height + 'px',
        zIndex: this.options.z_index,
        backgroundColor: this.options.color,
        opacity: 0.01,
        // IE8
        MsFilter: 'progid:DXImageTransform.Microsoft.Alpha(Opacity=1)',
        // IE5-7
        filter: 'alpha(opacity=1)'
      };

      Object.keys(properties).forEach(function (key) {
        element.style[key] = properties[key];
      });

      var handleClickEvent = function handleClickEvent(event) {
        EventBridge.stop(event);

        if (this.options.hide_on_click) {
          this.hide();
        }
      };

      EventBridge.add(element, 'click', handleClickEvent.bind(this));

      document.body.appendChild(element);
      this.covers.push(element);
      return element;
    }
  }, {
    key: 'addCovers',
    value: function addCovers(boxes) {
      this.removeCovers();
      boxes.forEach(this.addCover.bind(this));
    }
  }, {
    key: 'removeCovers',
    value: function removeCovers() {
      this.covers.forEach(function (element) {
        element.parentNode.removeChild(element);
      });
      this.covers = [];
    }
  }, {
    key: 'draw',
    value: function draw() {
      var _this2 = this;

      this.removeBackdrops();
      this.removeCovers();

      var target_boxes = [];

      this.element_monitor.elements.get().forEach(function (element) {
        var target_box = TheBox.getBox(element);
        if (target_box.width > 0 && target_box.height > 0) {
          target_box.pad(_this2.options.padding);
          target_boxes.push(target_box);
        }
      });

      this.addBackdrops(target_boxes);
      if (this.options.cover) {
        this.addCovers(target_boxes);
      }
    }

    /**
     * Shows backdrop. If element is provided, it is set before backdrop is shown.
     * @param {Element|string} [element] - Reference to an element or CSS selector.
     */

  }, {
    key: 'show',
    value: function show(element) {
      if (element) {
        this.set(element);
      }

      this.element_monitor.stop();
      this.draw();

      if (this.options.watch) {
        this.element_monitor.start();
      }

      this.is_active = true;
      this.options.onShow(this);
    }

    /**
     * Hides backdrop.
     */

  }, {
    key: 'hide',
    value: function hide() {
      this.element_monitor.stop();
      this.removeBackdrops();
      this.removeCovers();
      this.is_active = false;
      this.options.onHide(this);
    }
  }, {
    key: 'redraw',
    value: function redraw() {
      if (this.is_active) {
        this.draw();
      }
    }

    /**
     * Removes backdrop from document.
     */

  }, {
    key: 'destroy',
    value: function destroy() {
      this.hide();
    }
  }]);

  return Backdrop;
}();

export default Backdrop;

==> backdrop-2.0.7.tgz: package/module/index.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

import ElementMonitor from 'element-monitor';
import * as EventBridge from 'event-bridge';
import * as TheBox from 'the-dom-box';
import GapGrid from '@fczbkk/gap-grid';

var noop = function noop() {};

/**
 * Config object for Backdrop.
 * @typedef BackdropOptions
 * @property {string} backdrop_class - `"backdrop"` Class name added to all backdrop elements.
 * @property {number} z_index - `1000` Z-index added to all backdrop elements.
 * @property {number} padding - `5` Size of padding around target elements, in pixels.
 * @property {string} color - `"#000000"` Color of the backdrop elements.
 * @property {number} opacity - `0.5` Opacity of the backdrop elements. Must be number between 1 (fully opaque) and 0 (no opacity).
 * @property {boolean} hide_on_click - `true` If true, the backdrop will hide when user clicks on it.
 * @property {boolean} cover - `false` If true, the target elements will be covered by invisible elements which will prevent user from clicking on them. The cover elements also react to click when `hide_on_click` is enabled.
 * @property {boolean} watch - `false` If true, the backdrop will watch target elements and react to the changes in their position, size and/or visibility. This feature can have impact on performance, so it is turned off by default.
 * @property {number} watch_interval - `500` Interval between checks when watching for changes, in milliseconds.
 * @property {Function} onShow - Function to be called when backdrop is shown.
 * @property {Function} onHide - Function to be called when backdrop is hidden.
 */
var default_options = {
  backdrop_class: 'backdrop',
  z_index: 1000,
  padding: 5,
  color: '#000000',
  opacity: 0.5,
  hide_on_click: true,
  cover: false,
  watch: false,
  watch_interval: 500,
  onShow: noop,
  onHide: noop
};

/**
 * Class representing a Backdrop.
 * @name Backdrop
 */

var Backdrop = function () {

  /**
   * Create a Backdrop object.
   * @param {BackdropOptions} custom_options
   */
  function Backdrop() {
    var custom_options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

    _classCallCheck(this, Backdrop);

    this.backdrops = [];
    this.covers = [];
    this.is_active = false;
    this.options = _extends({}, default_options, custom_options);

    this.element_monitor = new ElementMonitor(null, {
      interval: this.options.watch_interval,
      onChange: this.draw.bind(this)
    });

    EventBridge.add(window, 'resize', this.redraw.bind(this));
  }

  /**
   * Updates existing options.
   * @param {BackdropOptions} custom_options
   */


  _createClass(Backdrop, [{
    key: 'setOptions',
    value: function setOptions() {
      var custom_options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

      _extends(this.options, custom_options);
    }

    /**
     * Adds element(s) to target elements.
     * @param {Element|string} element - Reference to an element or CSS selector.
     */

  }, {
    key: 'add',
    value: function add(element) {
      this.element_monitor.elements.add(element);
      this.redraw();
    }

    /**
     * Removes element(s) from target elements.
     * @param {Element|string} element - Reference to an element or CSS selector.
     */

  }, {
    key: 'remove',
    value: function remove(element) {
      this.element_monitor.elements.remove(element);
      this.redraw();
    }

    /**
     * Sets new target element(s).
     * @param {Element|string} element - Reference to an element or CSS selector.
     */

  }, {
    key: 'set',
    value: function set(element) {
      this.element_monitor.elements.set(element);
      this.redraw();
    }

    // When document is zoomed, element sizes and positions sometimes return numbers with crazy ammount of decimal places. This sometimes causes problem with blank lines showing in the backdrops. The easiest way to prevent this glitch is to round all the numbers to integers.

  }, {
    key: 'sanitizeEmptySpace',
    value: function sanitizeEmptySpace(box) {
      Object.keys(box).forEach(function (key) {
        box[key] = Math.round(box[key]);
      });
      return box;
    }
  }, {
    key: 'removeBackdrops',
    value: function removeBackdrops() {
      this.backdrops.forEach(function (element) {
        element.parentNode.removeChild(element);
      });
      this.backdrops = [];
    }
  }, {
    key: 'addBackdrops',
    value: function addBackdrops(gaps) {
      var _this = this;

      var canvas = TheBox.getBox('document');
      var gap_grid = new GapGrid(canvas, gaps, { apply_rounding: true });
      var empty_spaces = gap_grid.generate();

      empty_spaces.forEach(function (empty_space) {
        _this.backdrops.push(_this.createBackdrop(_this.sanitizeEmptySpace(empty_space)));
      });

      return this.backdrops;
    }
  }, {
    key: 'createBackdrop',
    value: function createBackdrop(box) {
      var element = document.createElement('div');
      element.className = this.options.backdrop_class;

      var ie_opacity = this.options.opacity * 100;

      var properties = {
        position: 'absolute',
        left: box.left + 'px',
        top: box.top + 'px',
        width: box.width + 'px',
        height: box.height + 'px',
        zIndex: this.options.z_index,
        backgroundColor: this.options.color,
        opacity: this.options.opacity,
        // IE8
        MsFilter: 'progid:DXImageTransform.Microsoft.Alpha(Opacity=' + ie_opacity + ')',
        // IE5-7
        filter: 'alpha(opacity=' + ie_opacity + ')'
      };

      Object.keys(properties).forEach(function (key) {
        element.style[key] = properties[key];
      });

      if (this.options.hide_on_click) {
        EventBridge.add(element, 'click', this.hide.bind(this));
      }

      document.body.appendChild(element);
      return element;
    }
  }, {
    key: 'addCover',
    value: function addCover(box) {
      var element = document.createElement('div');

      var properties = {
        position: 'absolute',
        left: box.left + 'px',
        top: box.top + 'px',
        width: box.width + 'px',
        height: box.height + 'px',
        zIndex: this.options.z_index,
        backgroundColor: this.options.color,
        opacity: 0.01,
        // IE8
        MsFilter: 'progid:DXImageTransform.Microsoft.Alpha(Opacity=1)',
        // IE5-7
        filter: 'alpha(opacity=1)'
      };

      Object.keys(properties).forEach(function (key) {
        element.style[key] = properties[key];
      });

      var handleClickEvent = function handleClickEvent(event) {
        EventBridge.stop(event);

        if (this.options.hide_on_click) {
          this.hide();
        }
      };

      EventBridge.add(element, 'click', handleClickEvent.bind(this));

      document.body.appendChild(element);
      this.covers.push(element);
      return element;
    }
  }, {
    key: 'addCovers',
    value: function addCovers(boxes) {
      this.removeCovers();
      boxes.forEach(this.addCover.bind(this));
    }
  }, {
    key: 'removeCovers',
    value: function removeCovers() {
      this.covers.forEach(function (element) {
        element.parentNode.removeChild(element);
      });
      this.covers = [];
    }
  }, {
    key: 'draw',
    value: function draw() {
      var _this2 = this;

      this.removeBackdrops();
      this.removeCovers();

      var target_boxes = [];

      this.element_monitor.elements.get().forEach(function (element) {
        var target_box = TheBox.getBox(element);
        if (target_box.width > 0 && target_box.height > 0) {
          target_box.pad(_this2.options.padding);
          target_boxes.push(target_box);
        }
      });

      this.addBackdrops(target_boxes);
      if (this.options.cover) {
        this.addCovers(target_boxes);
      }
    }

    /**
     * Shows backdrop. If element is provided, it is set before backdrop is shown.
     * @param {Element|string} [element] - Reference to an element or CSS selector.
     */

  }, {
    key: 'show',
    value: function show(element) {
      if (element) {
        this.set(element);
      }

      this.element_monitor.stop();
      this.draw();

      if (this.options.watch) {
        this.element_monitor.start();
      }

      this.is_active = true;
      this.options.onShow(this);
    }

    /**
     * Hides backdrop.
     */

  }, {
    key: 'hide',
    value: function hide() {
      this.element_monitor.stop();
      this.removeBackdrops();
      this.removeCovers();
      this.is_active = false;
      this.options.onHide(this);
    }
  }, {
    key: 'redraw',
    value: function redraw() {
      if (this.is_active) {
        this.draw();
      }
    }

    /**
     * Removes backdrop from document.
     */

  }, {
    key: 'destroy',
    value: function destroy() {
      this.hide();
    }
  }]);

  return Backdrop;
}();

export default Backdrop;
